==> haskell-cassava-0.5.4.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava
version:              0.5.4.1
visibility:           public
id:                   cassava-0.5.4.1-Glq4i28JePC4SrwZhjXu49
key:                  cassava-0.5.4.1-Glq4i28JePC4SrwZhjXu49
license:              BSD-3-Clause
copyright:
    (c) 2012 Johan Tibell
    (c) 2012 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           https://github.com/haskell-hvr/cassava
author:               Johan Tibell
homepage:             https://github.com/haskell-hvr/cassava
synopsis:             A CSV parsing and encoding library
description:
    @cassava@ is a library for parsing and encoding [RFC 4180](https://tools.ietf.org/html/rfc4180)
    compliant [comma-separated values (CSV)](https://en.wikipedia.org/wiki/Comma-separated_values) data,
    which is a textual line-oriented format commonly used for exchanging tabular data.

    @cassava@'\''s API includes support for

    - Index-based record-conversion
    - Name-based record-conversion
    - Typeclass directed conversion of fields and records
    - Built-in field-conversion instances for standard types
    - Customizable record-conversion instance derivation via GHC generics
    - Low-level [bytestring](https://hackage.haskell.org/package/bytestring) builders (see "Data.Csv.Builder")
    - Incremental decoding and encoding API (see "Data.Csv.Incremental")
    - Streaming API for constant-space decoding (see "Data.Csv.Streaming")

    Moreover, this library is designed to be easy to use; for instance, here'\''s a
    very simple example of encoding CSV data:

    >>> Data.Csv.encode [("John",27),("Jane",28)]
    "John,27\r\nJane,28\r\n"

    Please refer to the documentation in "Data.Csv" and the included [README](#readme) for more usage examples.

category:             Text, Web, CSV
abi:                  080d1c77ca39272a6a31f48aba1b7943
exposed:              True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming

hidden-modules:
    Data.Csv.Conversion Data.Csv.Conversion.Internal Data.Csv.Encoding
    Data.Csv.Types Data.Csv.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cassava-0.5.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cassava-0.5.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cassava-0.5.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava
hs-libraries:         HScassava-0.5.4.1-Glq4i28JePC4SrwZhjXu49
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1 array-0.5.4.0
    attoparsec-0.14.4-a7MjceIUMFKMmgfXk7t7H base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb
    scientific-0.3.8.0-KN45uED49ez8IbcjYjrLBN text-2.0.2
    text-short-0.1.6-Iw5qJriXjnZ5HQscs86bYL
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX
    vector-0.13.2.0-JDMr93x2QgFDQPvksTJZzq

haddock-interfaces:   /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html:         /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-0.5.4.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava
version:              0.5.4.1
visibility:           public
id:                   cassava-0.5.4.1-BNDoLN1lMf8AZ6wmPn3FqZ
key:                  cassava-0.5.4.1-BNDoLN1lMf8AZ6wmPn3FqZ
license:              BSD-3-Clause
copyright:
    (c) 2012 Johan Tibell
    (c) 2012 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           https://github.com/haskell-hvr/cassava
author:               Johan Tibell
homepage:             https://github.com/haskell-hvr/cassava
synopsis:             A CSV parsing and encoding library
description:
    @cassava@ is a library for parsing and encoding [RFC 4180](https://tools.ietf.org/html/rfc4180)
    compliant [comma-separated values (CSV)](https://en.wikipedia.org/wiki/Comma-separated_values) data,
    which is a textual line-oriented format commonly used for exchanging tabular data.

    @cassava@'\''s API includes support for

    - Index-based record-conversion
    - Name-based record-conversion
    - Typeclass directed conversion of fields and records
    - Built-in field-conversion instances for standard types
    - Customizable record-conversion instance derivation via GHC generics
    - Low-level [bytestring](https://hackage.haskell.org/package/bytestring) builders (see "Data.Csv.Builder")
    - Incremental decoding and encoding API (see "Data.Csv.Incremental")
    - Streaming API for constant-space decoding (see "Data.Csv.Streaming")

    Moreover, this library is designed to be easy to use; for instance, here'\''s a
    very simple example of encoding CSV data:

    >>> Data.Csv.encode [("John",27),("Jane",28)]
    "John,27\r\nJane,28\r\n"

    Please refer to the documentation in "Data.Csv" and the included [README](#readme) for more usage examples.

category:             Text, Web, CSV
abi:                  5f97bf4c7b8a0ff37fe9d5f0aa6dd0d4
exposed:              True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming

hidden-modules:
    Data.Csv.Conversion Data.Csv.Conversion.Internal Data.Csv.Encoding
    Data.Csv.Types Data.Csv.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cassava-0.5.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cassava-0.5.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cassava-0.5.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava
hs-libraries:         HScassava-0.5.4.1-BNDoLN1lMf8AZ6wmPn3FqZ
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1 array-0.5.4.0
    attoparsec-0.14.4-FKpKWqwLteZDlwxf33yCFk base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    hashable-1.4.4.0-KHdv63hvW7JkoOGsLWKac
    scientific-0.3.8.0-JD5EMEyFBUc5yMNfC55Oq6 text-2.0.2
    text-short-0.1.6-E7dU7XggPrS2MqFRVhPPLu
    unordered-containers-0.2.20-1i1FNKzvn6TI2R1AzcNrcz
    vector-0.13.2.0-FNdsFzivQrc5gVfjRMxS7n

haddock-interfaces:   /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html:         /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
